models
======

.. automodule:: zfit_physics.models
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   zfit_physics.models.pdf_argus
   zfit_physics.models.pdf_cmsshape
   zfit_physics.models.pdf_conv
   zfit_physics.models.pdf_cruijff
   zfit_physics.models.pdf_erfexp
   zfit_physics.models.pdf_example
   zfit_physics.models.pdf_kde
   zfit_physics.models.pdf_novosibirsk
   zfit_physics.models.pdf_relbw
   zfit_physics.models.pdf_tsallis
